@@ -13,4 +13,7 @@ class Database_Handler:
     
     def insert_record(self, keywords):
         return self.handler.insert_row(keywords)
+    
+    def update_record(self, keywords):
+        return self.handler.update_record(keywords)
     
\ No newline at end of file
