@@ -6,7 +6,7 @@ class Postgres_Handler:
     table_name_key = 'table_name'
     
     #Initializer that takes the values for connection
-    def __init__(self, user_name, password, host, port, database):
+    def __init__(self, user_name, password, host, database, port):
         self.user_name = user_name
         self.password = password
         self.host = host
